#!/bin/sh

. ./config.sh
export __MAKE_CONF=${START_PATH}/myfiles/conf/make.conf

if [ "$1" = "NOCLEAN" ]; then
  NOCLEAN="yes"
fi

if [ "${RELEASE}" = "5" ]; then
  CHFLAGS_BIN="/bin/chflags"
else
  CHFLAGS_BIN="/usr/bin/chflags"
fi

if [ -d "${JAIL_DIR}" ]; then
  echo -n "${JAIL_DIR} found. Remove all files? [Y]: "
  read ANSWER
  if [ "${ANSWER}" = "" -o "${ANSWER}" = "Y" -o "${ANSWER}" = "y" ]; then
    ${CHFLAGS_BIN} -R noschg ${JAIL_DIR} > /dev/null
    rm -rf ${JAIL_DIR}
  fi
fi

echo -n "Creating jail for miniBSD... "
mkdir -p ${JAIL_DIR}
echo "[OK]"
echo -n "Creating mtree..."
mtree -deU -f /usr/src/etc/mtree/BSD.root.dist -p ${JAIL_DIR} > /dev/null
mtree -deU -f /usr/src/etc/mtree/BSD.usr.dist -p ${JAIL_DIR}/usr/ > /dev/null
mtree -deU -f /usr/src/etc/mtree/BSD.var.dist -p ${JAIL_DIR}/var/ > /dev/null
echo "[OK]"

#Bug? This dir is not been created from BSD.usr.dist, 
#so, we have to create it manually
mkdir ${JAIL_DIR}/usr/share/nls/en_US.US-ASCII

if [ "${RELEASE}" = "5" ]; then
  FILES_LIST="minibsd_5.files"
else
  FILES_LIST="minibsd_4.files"
fi

for i in ${BIN_DIR}
do
  IS_GNU=`echo $i | cut -c 1-3`
  echo "Making in ${i}... "
  cd /usr/src/${i}
  for j in `ls`
  do
    if [ "${IS_GNU}" = "gnu" ]; then
      RIGHT_PATH=`echo $i | awk '{print substr($0,5,length($0)-4);}'`
      TO_COMPILE=`grep "^${RIGHT_PATH}/${j}" ${START_PATH}/${FILES_LIST}"`
    else
      TO_COMPILE=`grep "^${i}/${j}" ${START_PATH}/${FILES_LIST}"`
    fi
    if [ "${TO_COMPILE}" != "" ]; then
      echo "Compiling ${i}/${j}..."
      cd ${j}
      if [ "${NOCLEAN}" != "yes" ]; then
        make clean > /dev/null
      fi
      make > /dev/null
      make install DESTDIR=${JAIL_DIR} > /dev/null
      cd ..
    fi
  done
done
echo "[OK]"

echo -n "Copying /boot stuff..."
cp -rvp /boot/* ${JAIL_DIR}/boot > /dev/null
echo "[OK]"
