#!/bin/sh

. ./config.sh

echo -n "Device where your CF card is attached [${DEF_DEV}]: "
read DEVICE
if [ "${DEVICE}" = "" ]; then
  DEVICE="/dev/da0"
fi

echo "Retriving sectors information for ${DEVICE}"
DEF_SECTORS=`bsdlabel -A da0 | grep sectors/unit | cut -d\  -f 2`
if [ "${DEF_SECTORS}" = "" ]; then
  echo "Something goes wrong. Try to write a standard label in ${DEVICE}, with the following command:"
  echo "# /sbin/bsdlabel -w ${DEVICE}"
fi

echo -n "How many sectors do you want for the image [${DEF_SECTORS}]: " 
read SECTORS
if [ "${SECTORS}" = "" ]; then
  SECTORS="${DEF_SECTORS}" 
fi

echo -n "Creating ${DEST_FILE}... "
dd if=/dev/zero of=${DEST_FILE} bs=512 count=${SECTORS}
echo "[OK]"

echo -n "Generating minibsd-disk via md... "
if [ "${RELEASE}" = "5" ]; then
  SOFT_DEVICE="md4"
  mdconfig -a -t vnode -f ${DEST_FILE} -u 4
else
  SOFT_DEVICE="vn4"
  vnconfig -s labels -c ${SOFT_DEVICE} ${DEST_FILE}
fi
  
#Creating disk layout file
LAYOUT_FILE="disk_layout"
echo "a:  ${SECTORS}  0  4.2BSD  0 0 0" > ${LAYOUT_FILE}
disklabel -Brw ${SOFT_DEVICE} auto
disklabel -R ${SOFT_DEVICE} ${LAYOUT_FILE}
rm -f ${LAYOUT_FILE}

newfs -b 8192 -f 1024 -U /dev/${SOFT_DEVICE}a

if [ ! -d ${MOUNT_POINT} ]; then
  mkdir -p ${MOUNT_POINT}
fi

mount /dev/${SOFT_DEVICE}a ${MOUNT_POINT}

echo "Your flash card is now mounted i ${MOUNT_POINT}"
echo ""
echo ""
